#!/bin/bash

set -e

. ./ENV

LOCALLBIS=./locallibs
OPENAPI_GENERATOR=openapitools/openapi-generator-cli:v7.12.0

mkdir $LOCALLBIS && cd $LOCALLBIS

# --- DependencyTrack Client Library -----------------------------------------------------
curl ${DTRACK_API_URL}/api/openapi.json >dependencytrack-openapi.json

docker run -v $PWD:/work -u $UID $OPENAPI_GENERATOR \
  author template \
  -g python \
  -o /work/dependencytrack-openapi-custom-template

sed -i -e 's/import re/import regex as re/' dependencytrack-openapi-custom-template/model_anyof.mustache
sed -i -e 's/import re/import regex as re/' dependencytrack-openapi-custom-template/model_generic.mustache

docker run -v $PWD:/work -u $UID $OPENAPI_GENERATOR \
  generate \
  -i /work/dependencytrack-openapi.json \
  -g python \
  -o /work/dependencytrack-client \
  --package-name dependencytrack_api \
  -t /work/dependencytrack-openapi-custom-template

# --- Defectdojo Client Library ----------------------------------------------------------
curl ${DEFECTDOJO_URL}/api/v2/oa3/schema/?format=json >defectdojo-openapi.json

docker run -v $PWD:/work -u $UID $OPENAPI_GENERATOR \
  generate \
  -i /work/defectdojo-openapi.json \
  -g python \
  -o /work/defectdojo-client \
  --package-name defectdojo_api

cd ..

python3 -m venv .venv
. .venv/bin/activate
pip install -r requirements.txt
pip install -r $LOCALLBIS/dependencytrack-client/requirements.txt
pip install -r $LOCALLBIS/defectdojo-client/requirements.txt
